@@ -21,3 +21,5 @@ VID_API_VERSION = "/vid"
 CLAMP_URL   = "https://clamp.api.simpledemo.onap.org:30258"
 VES_URL = "http://ves.api.simpledemo.onap.org:30417"
 DMAAP_URL = "http://dmaap.api.simpledemo.onap.org:3904"
+NBI_URL = "https://nbi.api.simpledemo.onap.org:30274"
+NBI_API_VERSION = "/nbi/api/v4"
